<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl"
    xmlns="http://docbook.org/ns/docbook"
    xmlns:func="http://oxygenxml.com/samples/books"
    xmlns:xlink="http://www.w3.org/1999/xlink"
    exclude-result-prefixes="xs xd"
    xpath-default-namespace="http://oxygenxml.com/samples/books"
    version="2.0">
    <xd:doc scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> May 8, 2013</xd:p>
            <xd:p><xd:b>Author:</xd:b> Octavian Nadolu</xd:p>
            <xd:p>Generates a DocBook file containing a table with books.</xd:p>
        </xd:desc>
    </xd:doc>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Generates a table with books.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="books">
        <article xmlns:xlink="http://www.w3.org/1999/xlink" version="5.0">
            <title>The list of recommended books</title>
            <xsl:call-template name="processBooks">
                <xsl:with-param name="generateIndex" select="$generateIndex"/>
                <xsl:with-param name="groupByTechnology" select="$groupByTechnology"/>
            </xsl:call-template>
        </article>
    </xsl:template>
    
    <xsl:template name="generateTable">
        <xsl:param name="books"/>
        <informaltable frame="void">
            <col width="12%"/>
            <col width="88%"/> 
            <tbody>
                <xsl:apply-templates select="$books"/>
            </tbody>
        </informaltable>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Generates the a title for the given book category.</xd:p>
        </xd:desc>
        <xd:param name="category">The name of the book category.</xd:param>
    </xd:doc>
    <xsl:template name="generateCategoryTitle">
        <xsl:param name="category"/>
        <p>
            <xsl:value-of select="$category"/>
        </p>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Generates a link for a book the index.</xd:p>
        </xd:desc>
        <xd:param name="bookAnchor">The anchor of the reference.</xd:param>
        <xd:param name="bookName">The text displayed for the link.</xd:param>
        <xd:param name="bookAuthor">The author of the book.</xd:param>
    </xd:doc>
    <xsl:template name="createIndexItem">
        <xsl:param name="bookAnchor"/>
        <xsl:param name="bookName"/>
        <xsl:param name="bookAuthor"/>
        <para>
            <emphasis role="bold">
                <link  xlink:href="{concat('#', $bookAnchor)}">
                    <xsl:value-of select="$bookName"/>
                </link>
            </emphasis>
            <emphasis role="italic">
                - by <xsl:value-of select="$bookAuthor"/>
            </emphasis>
        </para>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Creates a row with two columns for each book.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="book">
        <!-- Book -->
        <tr>
            <td valign="top">
                <!--Image-->
                <xsl:apply-templates select="image"/>
            </td>
            <td>
                <anchor xml:id="{@anchor}"/>
                <!-- Title with link -->
                <xsl:variable name="title" select="title"/>
                <xsl:variable name="titleURI" select="@targeturi"/>
                
                <xsl:call-template name="linkTitle">
                    <xsl:with-param name="titleUri" select="$titleURI"/>
                    <xsl:with-param name="title" select="$title"/>
                </xsl:call-template>
                <!-- Author -->
                <para>
                    <emphasis role="italic">by 
                        <xsl:value-of select="author"/>
                    </emphasis>
                </para>
                <para>
                    <!-- Book info -->
                    <emphasis role="bold">Paperback: </emphasis><xsl:value-of select="paperback"/> | 
                    <emphasis role="bold">Publisher: </emphasis><xsl:value-of select="publisher"/> | 
                    <emphasis role="bold">Isbn: </emphasis><xsl:value-of select="isbn"/>
                </para>
                <!-- Description -->
                <xsl:apply-templates select="description"/>
            </td>
        </tr>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Creates an image element in a paragraph.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="image">
        <para>
            <mediaobject>
                <imageobject>
                    <imagedata fileref="{@src}" width="110" annotations="{@description}" />
                </imageobject>
            </mediaobject>
        </para>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Generates a title with link</xd:p>
        </xd:desc>
        <xd:param name="titleUri">The URI of the title</xd:param>
        <xd:param name="title">The value of the title</xd:param>
    </xd:doc>
    <xsl:template name="linkTitle">
        <xsl:param name="titleUri"/>
        <xsl:param name="title"/>
        <para>
            <emphasis role="bold">
                <link xlink:href="{$titleUri}">
                    <xsl:value-of select="$title"/>
                </link>
            </emphasis>
        </para>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>Creates a paragraph element.</xd:desc>
    </xd:doc>
    <xsl:template match="para">
        <para>
            <xsl:apply-templates/>
        </para>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>Creates an italic element.</xd:desc>
    </xd:doc>
    <xsl:template match="italic">
        <emphasis>
            <xsl:apply-templates/>
        </emphasis>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>Creates a list element.</xd:desc>
    </xd:doc>
    <xsl:template match="list">
        <itemizedlist>
            <xsl:apply-templates/>
        </itemizedlist>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>Creates a list item element.</xd:desc>
    </xd:doc>
    <xsl:template match="element">
        <listitem>
            <para><xsl:apply-templates/></para>
        </listitem>
    </xsl:template>
</xsl:stylesheet>
